==> scummvm_2.0.0+dfsg.orig.tar.xz: scummvm-2.0.0/engines/titanic/gfx/music_slider_speed.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef TITANIC_MUSIC_SLIDER_SPEED_H
#define TITANIC_MUSIC_SLIDER_SPEED_H

#include "titanic/gfx/music_slider.h"

namespace Titanic {

class CMusicSliderSpeed : public CMusicSlider {
	DECLARE_MESSAGE_MAP;
	bool MusicSettingChangedMsg(CMusicSettingChangedMsg *msg);
	bool EnterViewMsg(CEnterViewMsg *msg);
	bool QueryMusicControlSettingMsg(CQueryMusicControlSettingMsg *msg);
public:
	CLASSDEF;

	/**
	* Save the data for the class to file
	*/
	virtual void save(SimpleFile *file, int indent);

	/**
	* Load the data for the class from file
	*/
	virtual void load(SimpleFile *file);
};

} // End of namespace Titanic

#endif /* TITANIC_MUSIC_SLIDER_SPEED_H */

==> scummvm_2.5.1+dfsg.orig.tar.xz: scummvm-2.5.1/engines/titanic/gfx/music_slider_speed.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef TITANIC_MUSIC_SLIDER_SPEED_H
#define TITANIC_MUSIC_SLIDER_SPEED_H

#include "titanic/gfx/music_slider.h"

namespace Titanic {

class CMusicSliderSpeed : public CMusicSlider {
	DECLARE_MESSAGE_MAP;
	bool MusicSettingChangedMsg(CMusicSettingChangedMsg *msg);
	bool EnterViewMsg(CEnterViewMsg *msg);
	bool QueryMusicControlSettingMsg(CQueryMusicControlSettingMsg *msg);
public:
	CLASSDEF;

	/**
	* Save the data for the class to file
	*/
	void save(SimpleFile *file, int indent) override;

	/**
	* Load the data for the class from file
	*/
	void load(SimpleFile *file) override;
};

} // End of namespace Titanic

#endif /* TITANIC_MUSIC_SLIDER_SPEED_H */
